from ..core import Market


def test_core():
    market = Market()
    print '\ncoin()'
    print market.coin('bitcoin', limit=1)
    print '\nstats()'
    print market.stats()


if __name__ == '__main__':
    test_core()



import requests


class Market(object):  # A.1

    _session = None  # A.2

    def __init__(self, url='https://api.coinmarketcap.com/v1/', timeout=120):  # A.3
        self.url = url
        self.timeout = timeout

    @property  # A.8
    def session(self):  # A.4
        self._session = requests.Session()
        self._session.headers.update({'Content-Type': 'application/json'})
        self._session.headers.update({'User-agent': 'github:bitforce/wrapper-py-coinmarketcap'})
        return self._session

    def __request(self, endpoint, params):  # A.5
        response_object = self.session.get(self.url + endpoint, params=params, timeout=self.timeout)
        return response_object.json()

    def coin(self, currency='', **kwargs):  # A.6
            return self.__request('ticker/' + currency, {}.update(kwargs))

    def stats(self, **kwargs):  # A.7
            return self.__request('global/', {}.update(kwargs))



from setuptools import setup


setup(
    setup_cfg=True,
    setup_requires=['coinwrap'],
    install_requires=['requests'],
    license=open('LICENSE').read(),
    long_description=open('README.md').read()
)
